=====================================
 ``django_celery_monitor.humanize``
=====================================

.. contents::
    :local:
.. currentmodule:: django_celery_monitor.humanize

.. automodule:: django_celery_monitor.humanize
    :members:
